@@ -1,7 +1,7 @@
 use std::{collections::HashSet, fs};
 
 use crate::{linter::Linter, path::AbsPath};
-use anyhow::{bail, Context, Result};
+use anyhow::{bail, ensure, Context, Result};
 use glob::Pattern;
 use log::debug;
 use serde::{Deserialize, Serialize};
@@ -76,6 +76,9 @@ pub struct LintConfig {
     /// The paths in `{{PATHSFILE}}` will always be canoncalized (e.g. they are
     /// absolute paths with symlinks resolved).
     ///
+    /// Commands are run with the current working directory set to the parent
+    /// directory of the config file.
+    ///
     /// # Examples
     /// - Calling a Python script:
     /// ```toml
@@ -92,6 +95,9 @@ pub struct LintConfig {
     /// If `{{DRYRUN}}` is set, this command is expected to not make any changes
     /// to the user's environment, instead it should only print what it will do.
     ///
+    /// Commands are run with the current working directory set to the parent
+    /// directory of the config file.
+    ///
     /// # Examples
     /// - Calling a Python script:
     /// ```toml
@@ -115,12 +121,11 @@ pub fn get_linters_from_config(
             Vec::new()
         };
 
-        if lint_config.command.is_empty() {
-            bail!(
-                "Invalid linter configuration: '{}' has an empty command list.",
-                lint_config.code
-            );
-        }
+        ensure!(
+            !lint_config.command.is_empty(),
+            "Invalid linter configuration: '{}' has an empty command list.",
+            lint_config.code
+        );
         linters.push(Linter {
             code: lint_config.code,
             include_patterns,
@@ -130,14 +135,26 @@ pub fn get_linters_from_config(
             config_path: config_path.clone(),
         });
     }
-    debug!(
-        "Found linters: {:?}",
-        linters.iter().map(|l| &l.code).collect::<Vec<_>>()
-    );
+    let all_linters = linters
+        .iter()
+        .map(|l| &l.code)
+        .cloned()
+        .collect::<HashSet<_>>();
+
+    debug!("Found linters: {:?}", all_linters,);
 
     // Apply --take
     if let Some(taken_linters) = taken_linters {
         debug!("Taking linters: {:?}", taken_linters);
+        for linter in &taken_linters {
+            ensure!(
+                all_linters.contains(linter),
+                "Unknown linter specified in --take: {}. These linters are available: {:?}",
+                linter,
+                all_linters,
+            );
+        }
+
         linters = linters
             .into_iter()
             .filter(|linter| taken_linters.contains(&linter.code))
@@ -147,6 +164,14 @@ pub fn get_linters_from_config(
     // Apply --skip
     if let Some(skipped_linters) = skipped_linters {
         debug!("Skipping linters: {:?}", skipped_linters);
+        for linter in &skipped_linters {
+            ensure!(
+                all_linters.contains(linter),
+                "Unknown linter specified in --skip: {}. These linters are available: {:?}",
+                linter,
+                all_linters,
+            );
+        }
         linters = linters
             .into_iter()
             .filter(|linter| !skipped_linters.contains(&linter.code))
@@ -180,7 +205,7 @@ impl LintRunnerConfig {
     }
 }
 
-fn patterns_from_strs(pattern_strs: &Vec<String>) -> Result<Vec<Pattern>> {
+fn patterns_from_strs(pattern_strs: &[String]) -> Result<Vec<Pattern>> {
     pattern_strs
         .iter()
         .map(|pattern_str| {
