@@ -119,8 +119,8 @@ fn empty_command_fails() -> Result<()> {
 #[test]
 fn simple_linter() -> Result<()> {
     let lint_message = LintMessage {
-        path: Some("tests/integration_test.rs".to_string()),
-        line: Some(3),
+        path: Some("tests/fixtures/fake_source_file.rs".to_string()),
+        line: Some(9),
         char: Some(1),
         code: "DUMMY".to_string(),
         name: "dummy failure".to_string(),
@@ -133,8 +133,6 @@ fn simple_linter() -> Result<()> {
 
     let mut cmd = Command::cargo_bin("lintrunner")?;
     cmd.arg(format!("--config={}", config.path().to_str().unwrap()));
-    // Run the linter on this file.
-    cmd.arg("tests/integration_test.rs");
     cmd.assert().failure();
     assert_output_snapshot(&mut cmd)?;
 
@@ -148,7 +146,7 @@ fn simple_linter_fails_on_nonexistent_file() -> Result<()> {
             [[linter]]
             code = 'TESTLINTER'
             include_patterns = ['**']
-            command = ['wont_be_checked']
+            command = ['wont_be_run']
         ",
     )?;
 
@@ -228,3 +226,100 @@ fn linter_nonexistent_command() -> Result<()> {
 
     Ok(())
 }
+
+#[test]
+fn simple_linter_replacement_message() -> Result<()> {
+    let lint_message = LintMessage {
+        path: Some("tests/fixtures/fake_source_file.rs".to_string()),
+        line: Some(9),
+        char: Some(1),
+        code: "DUMMY".to_string(),
+        name: "dummy failure".to_string(),
+        severity: LintSeverity::Advice,
+        original: Some(
+            "\
+            foo\n\
+            bar\n\
+            baz\n\
+            foo\n\
+            bar\n\
+            baz\n\
+            foo\n\
+            bar\n\
+            baz\n\
+            foo\n\
+            bar\n\
+            baz\n\
+        "
+            .to_string(),
+        ),
+        replacement: Some(
+            "\
+            foo\n\
+            bar\n\
+            bat\n\
+            foo\n\
+            bar\n\
+            bat\n\
+            foo\n\
+            bar\n\
+            bat\n\
+            foo\n\
+            bar\n\
+            bat\n\
+        "
+            .to_string(),
+        ),
+        description: Some("A dummy linter failure".to_string()),
+    };
+    let config = temp_config_returning_msg(lint_message)?;
+
+    let mut cmd = Command::cargo_bin("lintrunner")?;
+    cmd.arg(format!("--config={}", config.path().to_str().unwrap()));
+    cmd.assert().failure();
+    assert_output_snapshot(&mut cmd)?;
+
+    Ok(())
+}
+
+#[test]
+fn take_nonexistent_linter() -> Result<()> {
+    let config = temp_config(
+        "\
+            [[linter]]
+            code = 'TESTLINTER'
+            include_patterns = ['**']
+            command = ['wont_be_run']
+        ",
+    )?;
+
+    let mut cmd = Command::cargo_bin("lintrunner")?;
+    cmd.arg(format!("--config={}", config.path().to_str().unwrap()));
+    cmd.arg("--take=MENOEXIST");
+
+    cmd.assert().failure();
+    assert_output_snapshot(&mut cmd)?;
+
+    Ok(())
+}
+
+#[test]
+fn skip_nonexistent_linter() -> Result<()> {
+    let config = temp_config(
+        "\
+            [[linter]]
+            code = 'TESTLINTER'
+            include_patterns = ['**']
+            command = ['wont_be_run']
+        ",
+    )?;
+
+    let mut cmd = Command::cargo_bin("lintrunner")?;
+    cmd.arg(format!("--config={}", config.path().to_str().unwrap()));
+    cmd.arg("--skip=MENOEXIST");
+
+    cmd.assert().failure();
+    assert_output_snapshot(&mut cmd)?;
+
+    Ok(())
+}
